//=============================================================================
// Project:    SLP - An Interpreter for Super Logic Programs / Static Semantics
// Module:     var.h
// Purpose:    Variable in a Formula
// Last Change:29.03.2001
// Language:   C++
// Author:     Stefan Brass
// Email:      Stefan.Brass@informatik.uni-giessen.de, sbrass@sis.pitt.edu
// Address:    Universitaet Giessen, Arndtstr. 2, 35392 Giessen, Germany
// Copyright:  (c) 2000-2001 by Stefan Brass
// Licence:    Distributed under the conditions of the GNU Public Licence.
//=============================================================================

//=============================================================================
// Include File Frame:
//=============================================================================

#ifndef	VAR_INCLUDED
#define VAR_INCLUDED

//=============================================================================
// Used Types and Macros:
//=============================================================================

#ifndef VER_INCLUDED
#include "ver.h"
#endif

#ifndef BOOL_INCLUDED
#include "bool.h"
#endif

#ifndef STR_INCLUDED
#include "str.h"
#endif

#ifndef CHECK_INCLUDED
#include "check.h"
#endif

//=============================================================================
// Private Constants:
//=============================================================================

//-----------------------------------------------------------------------------
// VAR_MAGIC: Magic number (identifies objects of this class for debugging).
//-----------------------------------------------------------------------------

#ifdef VER_DEBUG
static const long VAR_MAGIC = 0x5641520AL;	// 'VAR\n'
#endif

//=============================================================================
// Class for Variables in Formulas
//=============================================================================

class var_c {

	public:

//-----------------------------------------------------------------------------
// Methods:
//-----------------------------------------------------------------------------

	// Constructor:
	var_c(str_t name_ptr, str_t name_end);

	// Destructor:
	~var_c(void);

	// Name of this variable:
	inline str_t	name(void)
		{ return(CHECK_VALID(Name)); }

	// Print Variable:
	void	print(void);

//-----------------------------------------------------------------------------
// Debugging Support:
//-----------------------------------------------------------------------------

#ifdef	VER_DEBUG
	// Integrity Check:
	public:
	bool_t	valid(void);

	// Magic number (identifies objects of this class for debugging).
	private:
	long			Magic;			// Must be "VAR_MAGIC"
#endif

//-----------------------------------------------------------------------------
// Private Members:
//-----------------------------------------------------------------------------

	private:

	// Name: The variable name.
	str_t	Name;

//-----------------------------------------------------------------------------
// End of Class:
//-----------------------------------------------------------------------------

};

//-----------------------------------------------------------------------------
// Define pointer type:
//-----------------------------------------------------------------------------

typedef var_c *var_t;

//=============================================================================
// End of Include File:
//=============================================================================

#endif

